/* Copyright (c) 2024 Skyward Experimental Rocketry
 * Author: Federico Lolli
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

#include <filesystem/console/console_device.h>
#include <mavlink_lib/gemini/mavlink.h>
#include <radio/MavlinkDriver/MavlinkDriver.h>
#include <shared/mavlink/Utils.h>
#include <shared/radio/Radio.h>

using namespace miosix;
using namespace Boardcore;
using namespace Arpist;

// === DEFINITIONS ===

void onReceive(mavlink_message_t msg);

// === MAIN ===

int main()
{
    // start radio
    if (Radio::getInstance().start(onReceive))
    {
        TRACE("Radio start success\n");
    }
    else
    {
        TRACE("Radio start failed\n");
        return -1;
    }

    while (1)
    {
    }

    return 0;
}

void onReceive(mavlink_message_t msg)
{
    mavlink_payload_flight_tm_t payload;

    TRACE("Received message with ID %d\n", msg.msgid);
    mavlink_msg_payload_flight_tm_decode(&msg, &payload);
    TRACE("Received payload with timestamp %lld\n", payload.timestamp);
}
