/* Copyright (c) 2024 Skyward Experimental Rocketry
 * Author: Federico Lolli
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

#include <filesystem/console/console_device.h>
#include <mavlink_lib/gemini/mavlink.h>
#include <radio/MavlinkDriver/MavlinkDriver.h>
#include <shared/mavlink/Utils.h>
#include <shared/radio/Radio.h>

using namespace miosix;
using namespace Boardcore;
using namespace Arpist;

// === CONSTANTS ===

/** @brief End of transmission character */
constexpr uint8_t ACK = 0x06;

// === MAIN ===

int main()
{
    mavlink_message_t msg;

    // start radio
    if (Radio::getInstance().start([](const mavlink_message_t&) {}))
    {
        TRACE("Radio start success\n");
    }
    else
    {
        TRACE("Radio start failed\n");
        return -1;
    }

    while (true)
    {
        msg = readPacketFromSerial();
        DefaultConsole::instance().get()->writeBlock(&ACK, 1, 0);
        Radio::getInstance().sendMsg(msg);
    }

    return 0;
}
