use log::info;

/// Get the first serial port that contains "STM32" or "ST-LINK" in its product name
pub fn get_first_stm32_serial_port() -> Option<String> {
    let ports = serialport::available_ports().expect("No serial ports found!");
    for port in ports {
        if let serialport::SerialPortType::UsbPort(info) = port.port_type {
            if let Some(p) = info.product {
                if p.contains("STM32") || p.contains("ST-LINK") {
                    return Some(port.port_name);
                }
            }
        }
    }
    None
}

/// print stats (mean, median, std, etc)
pub fn print_stats(times: Vec<u128>) {
    let mean = times.iter().sum::<u128>() as f64 / times.len() as f64;
    let median = times[times.len() / 2] as f64;
    let std = times
        .iter()
        .map(|&x| (x as f64 - mean).powi(2))
        .sum::<f64>()
        .sqrt()
        / times.len() as f64;
    info!("Stats:");
    info!("Mean: {}ms", mean);
    info!("Median: {}ms", median);
    info!("Std: {}ms", std);
}
