use logos::Logos;

#[derive(Clone, Debug, PartialEq, Logos)]
pub enum Token {
    #[regex("[ \t]+")]
    Spaces,

    #[regex("[\n\r]")]
    Newline,

    #[regex("[0-9]+(\\.[0-9]+)?", |lex| lex.slice().parse().ok())]
    Num(f64),

    #[token("+")]
    OpAdd,

    #[token("-")]
    OpSub,

    #[token("*")]
    OpMul,

    #[token("/")]
    OpDiv,

    #[token("^")]
    OpPow,

    #[token("(")]
    LParen,

    #[token(")")]
    RParen,

    #[token("t")]
    Time,

    #[regex("T[+-]?[0-9]+(\\.[0-9]+)?", |lex| lex.slice()[1..].parse::<f64>().ok())]
    TimeRef(f64),

    #[regex(" ~ [0-9]+(\\.[0-9]+)?(Hz|kHz|MHz|GHz|THz)", |lex| lex.slice()[3..].to_string())]
    TimeStepFreq(String),

    #[regex("[a-z]+ *: *", |lex| lex.slice().trim().trim_end_matches(':').trim().to_string())]
    Parameter(String),

    #[regex("\\[[a-zA-Z.]+\\]", |lex| lex.slice().trim_matches('[').trim_matches(']').to_string())]
    BracketRef(String),

    #[regex("\\| *")]
    FillerLine,

    #[regex("@ +")]
    AtTimeLine,

    #[regex("= +")]
    SettingLine,

    #[regex("# +")]
    GeneratorLine,

    #[regex("\\\\ +")]
    ParameterLine,
}
